# This file has been generated


build_system = 'AppVeyor'
build_id = '31347505'
build_number = '479'
build_version = '1.0.479'
job_id = 'xrf4mt44ibq2afjf'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/stlib/build/job/xrf4mt44ibq2afjf'
